@@ -14,8 +14,16 @@
 #
 from __future__ import absolute_import
 
-from .delegate_directive import DelegateDirective
+from .input import Input
+from .input_request import InputRequest
+from .delegate_request_directive import DelegateRequestDirective
+from .delegation_period import DelegationPeriod
+from .updated_input_request import UpdatedInputRequest
 from .confirm_slot_directive import ConfirmSlotDirective
+from .delegate_directive import DelegateDirective
+from .updated_intent_request import UpdatedIntentRequest
+from .dynamic_entities_directive import DynamicEntitiesDirective
+from .updated_request import UpdatedRequest
 from .elicit_slot_directive import ElicitSlotDirective
 from .confirm_intent_directive import ConfirmIntentDirective
-from .dynamic_entities_directive import DynamicEntitiesDirective
+from .delegation_period_until import DelegationPeriodUntil
