@@ -35,6 +35,10 @@ class SetFocusCommand(Command):
     :type delay: (optional) int
     :param description: A user-provided description of this command.
     :type description: (optional) str
+    :param screen_lock: If true, disable the Interaction Timer.
+    :type screen_lock: (optional) bool
+    :param sequencer: Specify the sequencer that should execute this command.
+    :type sequencer: (optional) str
     :param when: If false, the execution of the command is skipped. Defaults to true.
     :type when: (optional) bool
     :param component_id: The ID of the component to set focus on.
@@ -45,6 +49,8 @@ class SetFocusCommand(Command):
         'object_type': 'str',
         'delay': 'int',
         'description': 'str',
+        'screen_lock': 'bool',
+        'sequencer': 'str',
         'when': 'bool',
         'component_id': 'str'
     }  # type: Dict
@@ -53,19 +59,25 @@ class SetFocusCommand(Command):
         'object_type': 'type',
         'delay': 'delay',
         'description': 'description',
+        'screen_lock': 'screenLock',
+        'sequencer': 'sequencer',
         'when': 'when',
         'component_id': 'componentId'
     }  # type: Dict
     supports_multiple_types = False
 
-    def __init__(self, delay=None, description=None, when=None, component_id=None):
-        # type: (Union[int, str, None], Optional[str], Optional[bool], Optional[str]) -> None
+    def __init__(self, delay=None, description=None, screen_lock=None, sequencer=None, when=None, component_id=None):
+        # type: (Union[int, str, None], Optional[str], Optional[bool], Optional[str], Optional[bool], Optional[str]) -> None
         """Changes the actionable component that is in focus. Only one component may have focus at a time.
 
         :param delay: The delay in milliseconds before this command starts executing; must be non-negative. Defaults to 0.
         :type delay: (optional) int
         :param description: A user-provided description of this command.
         :type description: (optional) str
+        :param screen_lock: If true, disable the Interaction Timer.
+        :type screen_lock: (optional) bool
+        :param sequencer: Specify the sequencer that should execute this command.
+        :type sequencer: (optional) str
         :param when: If false, the execution of the command is skipped. Defaults to true.
         :type when: (optional) bool
         :param component_id: The ID of the component to set focus on.
@@ -74,7 +86,7 @@ class SetFocusCommand(Command):
         self.__discriminator_value = "SetFocus"  # type: str
 
         self.object_type = self.__discriminator_value
-        super(SetFocusCommand, self).__init__(object_type=self.__discriminator_value, delay=delay, description=description, when=when)
+        super(SetFocusCommand, self).__init__(object_type=self.__discriminator_value, delay=delay, description=description, screen_lock=screen_lock, sequencer=sequencer, when=when)
         self.component_id = component_id
 
     def to_dict(self):
