@@ -37,6 +37,10 @@ class SpeakItemCommand(Command):
     :type delay: (optional) int
     :param description: A user-provided description of this command.
     :type description: (optional) str
+    :param screen_lock: If true, disable the Interaction Timer.
+    :type screen_lock: (optional) bool
+    :param sequencer: Specify the sequencer that should execute this command.
+    :type sequencer: (optional) str
     :param when: If false, the execution of the command is skipped. Defaults to true.
     :type when: (optional) bool
     :param align: 
@@ -53,6 +57,8 @@ class SpeakItemCommand(Command):
         'object_type': 'str',
         'delay': 'int',
         'description': 'str',
+        'screen_lock': 'bool',
+        'sequencer': 'str',
         'when': 'bool',
         'align': 'ask_sdk_model.interfaces.alexa.presentation.apl.align.Align',
         'component_id': 'str',
@@ -64,6 +70,8 @@ class SpeakItemCommand(Command):
         'object_type': 'type',
         'delay': 'delay',
         'description': 'description',
+        'screen_lock': 'screenLock',
+        'sequencer': 'sequencer',
         'when': 'when',
         'align': 'align',
         'component_id': 'componentId',
@@ -72,14 +80,18 @@ class SpeakItemCommand(Command):
     }  # type: Dict
     supports_multiple_types = False
 
-    def __init__(self, delay=None, description=None, when=None, align=None, component_id=None, highlight_mode=None, minimum_dwell_time=None):
-        # type: (Union[int, str, None], Optional[str], Optional[bool], Optional[Align_70ae0466], Optional[str], Optional[HighlightMode_9965984d], Union[int, str, None]) -> None
+    def __init__(self, delay=None, description=None, screen_lock=None, sequencer=None, when=None, align=None, component_id=None, highlight_mode=None, minimum_dwell_time=None):
+        # type: (Union[int, str, None], Optional[str], Optional[bool], Optional[str], Optional[bool], Optional[Align_70ae0466], Optional[str], Optional[HighlightMode_9965984d], Union[int, str, None]) -> None
         """Reads the contents of a single item on the screen. By default the item will be scrolled into view if it is not currently visible.
 
         :param delay: The delay in milliseconds before this command starts executing; must be non-negative. Defaults to 0.
         :type delay: (optional) int
         :param description: A user-provided description of this command.
         :type description: (optional) str
+        :param screen_lock: If true, disable the Interaction Timer.
+        :type screen_lock: (optional) bool
+        :param sequencer: Specify the sequencer that should execute this command.
+        :type sequencer: (optional) str
         :param when: If false, the execution of the command is skipped. Defaults to true.
         :type when: (optional) bool
         :param align: 
@@ -94,7 +106,7 @@ class SpeakItemCommand(Command):
         self.__discriminator_value = "SpeakItem"  # type: str
 
         self.object_type = self.__discriminator_value
-        super(SpeakItemCommand, self).__init__(object_type=self.__discriminator_value, delay=delay, description=description, when=when)
+        super(SpeakItemCommand, self).__init__(object_type=self.__discriminator_value, delay=delay, description=description, screen_lock=screen_lock, sequencer=sequencer, when=when)
         self.align = align
         self.component_id = component_id
         self.highlight_mode = highlight_mode
