@@ -14,28 +14,28 @@
 #
 from __future__ import absolute_import
 
-from .reminder_deleted_event_request import ReminderDeletedEventRequest
-from .reminder import Reminder
-from .reminder_started_event_request import ReminderStartedEventRequest
-from .error import Error
+from .get_reminders_response import GetRemindersResponse
+from .reminder_created_event_request import ReminderCreatedEventRequest
+from .reminder_deleted_event import ReminderDeletedEvent
+from .spoken_text import SpokenText
+from .trigger_type import TriggerType
+from .recurrence_freq import RecurrenceFreq
 from .get_reminder_response import GetReminderResponse
 from .alert_info import AlertInfo
-from .trigger import Trigger
-from .reminder_response import ReminderResponse
-from .get_reminders_response import GetRemindersResponse
-from .reminder_updated_event_request import ReminderUpdatedEventRequest
-from .reminder_status_changed_event_request import ReminderStatusChangedEventRequest
-from .recurrence_freq import RecurrenceFreq
-from .spoken_text import SpokenText
-from .alert_info_spoken_info import AlertInfoSpokenInfo
 from .status import Status
-from .recurrence import Recurrence
-from .recurrence_day import RecurrenceDay
-from .reminder_deleted_event import ReminderDeletedEvent
-from .push_notification_status import PushNotificationStatus
-from .trigger_type import TriggerType
-from .reminder_created_event_request import ReminderCreatedEventRequest
+from .spoken_info import SpokenInfo
 from .reminder_request import ReminderRequest
+from .recurrence import Recurrence
+from .error import Error
+from .reminder_management_service_client import ReminderManagementServiceClient
+from .reminder_status_changed_event_request import ReminderStatusChangedEventRequest
+from .reminder import Reminder
+from .reminder_updated_event_request import ReminderUpdatedEventRequest
+from .trigger import Trigger
+from .reminder_started_event_request import ReminderStartedEventRequest
+from .reminder_response import ReminderResponse
 from .event import Event
 from .push_notification import PushNotification
-from .reminder_management_service_client import ReminderManagementServiceClient
+from .push_notification_status import PushNotificationStatus
+from .reminder_deleted_event_request import ReminderDeletedEventRequest
+from .recurrence_day import RecurrenceDay
